@@ -47,6 +47,7 @@ from pytensor.tensor.type import (
     zscalar,
 )
 from pytensor.tensor.type_other import NoneConst, NoneTypeT, SliceType, make_slice
+from pytensor.tensor.variable import TensorVariable
 
 
 _logger = logging.getLogger("pytensor.tensor.subtensor")
@@ -473,6 +474,13 @@ def group_indices(indices):
     return idx_groups
 
 
+def _non_contiguous_adv_indexing(indices) -> bool:
+    """Check if the advanced indexing is non-contiguous (i.e., split by basic indexing)."""
+    idx_groups = group_indices(indices)
+    # This means that there are at least two groups of advanced indexing separated by basic indexing
+    return len(idx_groups) > 3 or (len(idx_groups) == 3 and not idx_groups[0][0])
+
+
 def indexed_result_shape(array_shape, indices, indices_are_shapes=False):
     """Compute the symbolic shape resulting from `a[indices]` for `a.shape == array_shape`.
 
@@ -497,8 +505,7 @@ def indexed_result_shape(array_shape, indices, indices_are_shapes=False):
     remaining_dims = range(pytensor.tensor.basic.get_vector_length(array_shape))
     idx_groups = group_indices(indices)
 
-    if len(idx_groups) > 3 or (len(idx_groups) == 3 and not idx_groups[0][0]):
-        # This means that there are at least two groups of advanced indexing separated by basic indexing
+    if _non_contiguous_adv_indexing(indices):
         # In this case NumPy places the advanced index groups in the front of the array
         # https://numpy.org/devdocs/user/basics.indexing.html#combining-advanced-and-basic-indexing
         idx_groups = sorted(idx_groups, key=lambda x: x[0])
@@ -2174,7 +2181,7 @@ class AdvancedIncSubtensor1(COp):
         else:
             msg += ",inc"
 
-        return self.__class__.__name__ + "{%s}" % msg
+        return self.__class__.__name__ + f"{{{msg}}}"
 
     def make_node(self, x, y, ilist):
         x_ = as_tensor_variable(x)
@@ -2682,10 +2689,68 @@ class AdvancedSubtensor(Op):
             rest
         )
 
+    @staticmethod
+    def non_contiguous_adv_indexing(node: Apply) -> bool:
+        """
+        Check if the advanced indexing is non-contiguous (i.e. interrupted by basic indexing).
+
+        This function checks if the advanced indexing is non-contiguous,
+        in which case the advanced index dimensions are placed on the left of the
+        output array, regardless of their opriginal position.
+
+        See: https://numpy.org/doc/stable/user/basics.indexing.html#combining-advanced-and-basic-indexing
+
+
+        Parameters
+        ----------
+        node : Apply
+            The node of the AdvancedSubtensor operation.
+
+        Returns
+        -------
+        bool
+            True if the advanced indexing is non-contiguous, False otherwise.
+        """
+        _, *idxs = node.inputs
+        return _non_contiguous_adv_indexing(idxs)
+
 
 advanced_subtensor = AdvancedSubtensor()
 
 
+@_vectorize_node.register(AdvancedSubtensor)
+def vectorize_advanced_subtensor(op: AdvancedSubtensor, node, *batch_inputs):
+    x, *idxs = node.inputs
+    batch_x, *batch_idxs = batch_inputs
+
+    x_is_batched = x.type.ndim < batch_x.type.ndim
+    idxs_are_batched = any(
+        batch_idx.type.ndim > idx.type.ndim
+        for batch_idx, idx in zip(batch_idxs, idxs)
+        if isinstance(batch_idx, TensorVariable)
+    )
+
+    if idxs_are_batched or (x_is_batched and op.non_contiguous_adv_indexing(node)):
+        # Fallback to Blockwise if idxs are batched or if we have non contiguous advanced indexing
+        # which would put the indexed results to the left of the batch dimensions!
+        # TODO: Not all cases must be handled by Blockwise, but the logic is complex
+
+        # Blockwise doesn't accept None or Slices types so we raise informative error here
+        # TODO: Implement these internally, so Blockwise is always a safe fallback
+        if any(not isinstance(idx, TensorVariable) for idx in idxs):
+            raise NotImplementedError(
+                "Vectorized AdvancedSubtensor with batched indexes or non-contiguous advanced indexing "
+                "and slices or newaxis is currently not supported."
+            )
+        else:
+            return vectorize_node_fallback(op, node, batch_x, *batch_idxs)
+
+    # Otherwise we just need to add None slices for every new batch dim
+    x_batch_ndim = batch_x.type.ndim - x.type.ndim
+    empty_slices = (slice(None),) * x_batch_ndim
+    return op.make_node(batch_x, *empty_slices, *batch_idxs)
+
+
 class AdvancedIncSubtensor(Op):
     """Increments a subtensor using advanced indexing."""
 
